==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkOpenFOAMReader.java <==
// java wrapper for vtkOpenFOAMReader object
//

package vtk;
import vtk.*;

public class vtkOpenFOAMReader extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int CanReadFile_2(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_2(id0); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetFileName_4();
  public String GetFileName()
    { return GetFileName_4(); }

  private native int GetNumberOfCellArrays_5();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_5(); }

  private native int GetCellArrayStatus_6(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_6(id0); }

  private native void SetCellArrayStatus_7(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_7(id0,id1); }

  private native String GetCellArrayName_8(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_8(id0); }

  private native void DisableAllCellArrays_9();
  public void DisableAllCellArrays()
    { DisableAllCellArrays_9(); }

  private native void EnableAllCellArrays_10();
  public void EnableAllCellArrays()
    { EnableAllCellArrays_10(); }

  private native int GetNumberOfPointArrays_11();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_11(); }

  private native int GetPointArrayStatus_12(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_12(id0); }

  private native void SetPointArrayStatus_13(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_13(id0,id1); }

  private native String GetPointArrayName_14(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_14(id0); }

  private native void DisableAllPointArrays_15();
  public void DisableAllPointArrays()
    { DisableAllPointArrays_15(); }

  private native void EnableAllPointArrays_16();
  public void EnableAllPointArrays()
    { EnableAllPointArrays_16(); }

  private native int GetNumberOfLagrangianArrays_17();
  public int GetNumberOfLagrangianArrays()
    { return GetNumberOfLagrangianArrays_17(); }

  private native int GetLagrangianArrayStatus_18(String id0);
  public int GetLagrangianArrayStatus(String id0)
    { return GetLagrangianArrayStatus_18(id0); }

  private native void SetLagrangianArrayStatus_19(String id0,int id1);
  public void SetLagrangianArrayStatus(String id0,int id1)
    { SetLagrangianArrayStatus_19(id0,id1); }

  private native String GetLagrangianArrayName_20(int id0);
  public String GetLagrangianArrayName(int id0)
    { return GetLagrangianArrayName_20(id0); }

  private native void DisableAllLagrangianArrays_21();
  public void DisableAllLagrangianArrays()
    { DisableAllLagrangianArrays_21(); }

  private native void EnableAllLagrangianArrays_22();
  public void EnableAllLagrangianArrays()
    { EnableAllLagrangianArrays_22(); }

  private native int GetNumberOfPatchArrays_23();
  public int GetNumberOfPatchArrays()
    { return GetNumberOfPatchArrays_23(); }

  private native int GetPatchArrayStatus_24(String id0);
  public int GetPatchArrayStatus(String id0)
    { return GetPatchArrayStatus_24(id0); }

  private native void SetPatchArrayStatus_25(String id0,int id1);
  public void SetPatchArrayStatus(String id0,int id1)
    { SetPatchArrayStatus_25(id0,id1); }

  private native String GetPatchArrayName_26(int id0);
  public String GetPatchArrayName(int id0)
    { return GetPatchArrayName_26(id0); }

  private native void DisableAllPatchArrays_27();
  public void DisableAllPatchArrays()
    { DisableAllPatchArrays_27(); }

  private native void EnableAllPatchArrays_28();
  public void EnableAllPatchArrays()
    { EnableAllPatchArrays_28(); }

  private native void SetCreateCellToPoint_29(int id0);
  public void SetCreateCellToPoint(int id0)
    { SetCreateCellToPoint_29(id0); }

  private native int GetCreateCellToPoint_30();
  public int GetCreateCellToPoint()
    { return GetCreateCellToPoint_30(); }

  private native void CreateCellToPointOn_31();
  public void CreateCellToPointOn()
    { CreateCellToPointOn_31(); }

  private native void CreateCellToPointOff_32();
  public void CreateCellToPointOff()
    { CreateCellToPointOff_32(); }

  private native void SetCacheMesh_33(int id0);
  public void SetCacheMesh(int id0)
    { SetCacheMesh_33(id0); }

  private native int GetCacheMesh_34();
  public int GetCacheMesh()
    { return GetCacheMesh_34(); }

  private native void CacheMeshOn_35();
  public void CacheMeshOn()
    { CacheMeshOn_35(); }

  private native void CacheMeshOff_36();
  public void CacheMeshOff()
    { CacheMeshOff_36(); }

  private native void SetDecomposePolyhedra_37(int id0);
  public void SetDecomposePolyhedra(int id0)
    { SetDecomposePolyhedra_37(id0); }

  private native int GetDecomposePolyhedra_38();
  public int GetDecomposePolyhedra()
    { return GetDecomposePolyhedra_38(); }

  private native void DecomposePolyhedraOn_39();
  public void DecomposePolyhedraOn()
    { DecomposePolyhedraOn_39(); }

  private native void DecomposePolyhedraOff_40();
  public void DecomposePolyhedraOff()
    { DecomposePolyhedraOff_40(); }

  private native void SetPositionsIsIn13Format_41(int id0);
  public void SetPositionsIsIn13Format(int id0)
    { SetPositionsIsIn13Format_41(id0); }

  private native int GetPositionsIsIn13Format_42();
  public int GetPositionsIsIn13Format()
    { return GetPositionsIsIn13Format_42(); }

  private native void PositionsIsIn13FormatOn_43();
  public void PositionsIsIn13FormatOn()
    { PositionsIsIn13FormatOn_43(); }

  private native void PositionsIsIn13FormatOff_44();
  public void PositionsIsIn13FormatOff()
    { PositionsIsIn13FormatOff_44(); }

  private native void SetListTimeStepsByControlDict_45(int id0);
  public void SetListTimeStepsByControlDict(int id0)
    { SetListTimeStepsByControlDict_45(id0); }

  private native int GetListTimeStepsByControlDict_46();
  public int GetListTimeStepsByControlDict()
    { return GetListTimeStepsByControlDict_46(); }

  private native void ListTimeStepsByControlDictOn_47();
  public void ListTimeStepsByControlDictOn()
    { ListTimeStepsByControlDictOn_47(); }

  private native void ListTimeStepsByControlDictOff_48();
  public void ListTimeStepsByControlDictOff()
    { ListTimeStepsByControlDictOff_48(); }

  private native void SetAddDimensionsToArrayNames_49(int id0);
  public void SetAddDimensionsToArrayNames(int id0)
    { SetAddDimensionsToArrayNames_49(id0); }

  private native int GetAddDimensionsToArrayNames_50();
  public int GetAddDimensionsToArrayNames()
    { return GetAddDimensionsToArrayNames_50(); }

  private native void AddDimensionsToArrayNamesOn_51();
  public void AddDimensionsToArrayNamesOn()
    { AddDimensionsToArrayNamesOn_51(); }

  private native void AddDimensionsToArrayNamesOff_52();
  public void AddDimensionsToArrayNamesOff()
    { AddDimensionsToArrayNamesOff_52(); }

  private native void SetReadZones_53(int id0);
  public void SetReadZones(int id0)
    { SetReadZones_53(id0); }

  private native int GetReadZones_54();
  public int GetReadZones()
    { return GetReadZones_54(); }

  private native void ReadZonesOn_55();
  public void ReadZonesOn()
    { ReadZonesOn_55(); }

  private native void ReadZonesOff_56();
  public void ReadZonesOff()
    { ReadZonesOff_56(); }

  private native void SetRefresh_57();
  public void SetRefresh()
    { SetRefresh_57(); }

  private native void SetParent_58(vtkOpenFOAMReader id0);
  public void SetParent(vtkOpenFOAMReader id0)
    { SetParent_58(id0); }

  private native int MakeInformationVector_59(vtkInformationVector id0,String id1);
  public int MakeInformationVector(vtkInformationVector id0,String id1)
    { return MakeInformationVector_59(id0,id1); }

  private native boolean SetTimeValue_60(double id0);
  public boolean SetTimeValue(double id0)
    { return SetTimeValue_60(id0); }

  private native long GetTimeValues_61();
  public vtkDoubleArray GetTimeValues() {
    long temp = GetTimeValues_61();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int MakeMetaDataAtTimeStep_62(boolean id0);
  public int MakeMetaDataAtTimeStep(boolean id0)
    { return MakeMetaDataAtTimeStep_62(id0); }

  public vtkOpenFOAMReader() { super(); }

  public vtkOpenFOAMReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-7-armv6h.pkg.tar.xz: vtk/vtkOpenFOAMReader.java <==
// java wrapper for vtkOpenFOAMReader object
//

package vtk;
import vtk.*;

public class vtkOpenFOAMReader extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int CanReadFile_2(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_2(id0); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetFileName_4();
  public String GetFileName()
    { return GetFileName_4(); }

  private native int GetNumberOfCellArrays_5();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_5(); }

  private native int GetCellArrayStatus_6(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_6(id0); }

  private native void SetCellArrayStatus_7(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_7(id0,id1); }

  private native String GetCellArrayName_8(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_8(id0); }

  private native void DisableAllCellArrays_9();
  public void DisableAllCellArrays()
    { DisableAllCellArrays_9(); }

  private native void EnableAllCellArrays_10();
  public void EnableAllCellArrays()
    { EnableAllCellArrays_10(); }

  private native int GetNumberOfPointArrays_11();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_11(); }

  private native int GetPointArrayStatus_12(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_12(id0); }

  private native void SetPointArrayStatus_13(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_13(id0,id1); }

  private native String GetPointArrayName_14(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_14(id0); }

  private native void DisableAllPointArrays_15();
  public void DisableAllPointArrays()
    { DisableAllPointArrays_15(); }

  private native void EnableAllPointArrays_16();
  public void EnableAllPointArrays()
    { EnableAllPointArrays_16(); }

  private native int GetNumberOfLagrangianArrays_17();
  public int GetNumberOfLagrangianArrays()
    { return GetNumberOfLagrangianArrays_17(); }

  private native int GetLagrangianArrayStatus_18(String id0);
  public int GetLagrangianArrayStatus(String id0)
    { return GetLagrangianArrayStatus_18(id0); }

  private native void SetLagrangianArrayStatus_19(String id0,int id1);
  public void SetLagrangianArrayStatus(String id0,int id1)
    { SetLagrangianArrayStatus_19(id0,id1); }

  private native String GetLagrangianArrayName_20(int id0);
  public String GetLagrangianArrayName(int id0)
    { return GetLagrangianArrayName_20(id0); }

  private native void DisableAllLagrangianArrays_21();
  public void DisableAllLagrangianArrays()
    { DisableAllLagrangianArrays_21(); }

  private native void EnableAllLagrangianArrays_22();
  public void EnableAllLagrangianArrays()
    { EnableAllLagrangianArrays_22(); }

  private native int GetNumberOfPatchArrays_23();
  public int GetNumberOfPatchArrays()
    { return GetNumberOfPatchArrays_23(); }

  private native int GetPatchArrayStatus_24(String id0);
  public int GetPatchArrayStatus(String id0)
    { return GetPatchArrayStatus_24(id0); }

  private native void SetPatchArrayStatus_25(String id0,int id1);
  public void SetPatchArrayStatus(String id0,int id1)
    { SetPatchArrayStatus_25(id0,id1); }

  private native String GetPatchArrayName_26(int id0);
  public String GetPatchArrayName(int id0)
    { return GetPatchArrayName_26(id0); }

  private native void DisableAllPatchArrays_27();
  public void DisableAllPatchArrays()
    { DisableAllPatchArrays_27(); }

  private native void EnableAllPatchArrays_28();
  public void EnableAllPatchArrays()
    { EnableAllPatchArrays_28(); }

  private native void SetCreateCellToPoint_29(int id0);
  public void SetCreateCellToPoint(int id0)
    { SetCreateCellToPoint_29(id0); }

  private native int GetCreateCellToPoint_30();
  public int GetCreateCellToPoint()
    { return GetCreateCellToPoint_30(); }

  private native void CreateCellToPointOn_31();
  public void CreateCellToPointOn()
    { CreateCellToPointOn_31(); }

  private native void CreateCellToPointOff_32();
  public void CreateCellToPointOff()
    { CreateCellToPointOff_32(); }

  private native void SetCacheMesh_33(int id0);
  public void SetCacheMesh(int id0)
    { SetCacheMesh_33(id0); }

  private native int GetCacheMesh_34();
  public int GetCacheMesh()
    { return GetCacheMesh_34(); }

  private native void CacheMeshOn_35();
  public void CacheMeshOn()
    { CacheMeshOn_35(); }

  private native void CacheMeshOff_36();
  public void CacheMeshOff()
    { CacheMeshOff_36(); }

  private native void SetDecomposePolyhedra_37(int id0);
  public void SetDecomposePolyhedra(int id0)
    { SetDecomposePolyhedra_37(id0); }

  private native int GetDecomposePolyhedra_38();
  public int GetDecomposePolyhedra()
    { return GetDecomposePolyhedra_38(); }

  private native void DecomposePolyhedraOn_39();
  public void DecomposePolyhedraOn()
    { DecomposePolyhedraOn_39(); }

  private native void DecomposePolyhedraOff_40();
  public void DecomposePolyhedraOff()
    { DecomposePolyhedraOff_40(); }

  private native void SetPositionsIsIn13Format_41(int id0);
  public void SetPositionsIsIn13Format(int id0)
    { SetPositionsIsIn13Format_41(id0); }

  private native int GetPositionsIsIn13Format_42();
  public int GetPositionsIsIn13Format()
    { return GetPositionsIsIn13Format_42(); }

  private native void PositionsIsIn13FormatOn_43();
  public void PositionsIsIn13FormatOn()
    { PositionsIsIn13FormatOn_43(); }

  private native void PositionsIsIn13FormatOff_44();
  public void PositionsIsIn13FormatOff()
    { PositionsIsIn13FormatOff_44(); }

  private native void SetSkipZeroTime_45(boolean id0);
  public void SetSkipZeroTime(boolean id0)
    { SetSkipZeroTime_45(id0); }

  private native boolean GetSkipZeroTime_46();
  public boolean GetSkipZeroTime()
    { return GetSkipZeroTime_46(); }

  private native void SkipZeroTimeOn_47();
  public void SkipZeroTimeOn()
    { SkipZeroTimeOn_47(); }

  private native void SkipZeroTimeOff_48();
  public void SkipZeroTimeOff()
    { SkipZeroTimeOff_48(); }

  private native void SetListTimeStepsByControlDict_49(int id0);
  public void SetListTimeStepsByControlDict(int id0)
    { SetListTimeStepsByControlDict_49(id0); }

  private native int GetListTimeStepsByControlDict_50();
  public int GetListTimeStepsByControlDict()
    { return GetListTimeStepsByControlDict_50(); }

  private native void ListTimeStepsByControlDictOn_51();
  public void ListTimeStepsByControlDictOn()
    { ListTimeStepsByControlDictOn_51(); }

  private native void ListTimeStepsByControlDictOff_52();
  public void ListTimeStepsByControlDictOff()
    { ListTimeStepsByControlDictOff_52(); }

  private native void SetAddDimensionsToArrayNames_53(int id0);
  public void SetAddDimensionsToArrayNames(int id0)
    { SetAddDimensionsToArrayNames_53(id0); }

  private native int GetAddDimensionsToArrayNames_54();
  public int GetAddDimensionsToArrayNames()
    { return GetAddDimensionsToArrayNames_54(); }

  private native void AddDimensionsToArrayNamesOn_55();
  public void AddDimensionsToArrayNamesOn()
    { AddDimensionsToArrayNamesOn_55(); }

  private native void AddDimensionsToArrayNamesOff_56();
  public void AddDimensionsToArrayNamesOff()
    { AddDimensionsToArrayNamesOff_56(); }

  private native void SetReadZones_57(int id0);
  public void SetReadZones(int id0)
    { SetReadZones_57(id0); }

  private native int GetReadZones_58();
  public int GetReadZones()
    { return GetReadZones_58(); }

  private native void ReadZonesOn_59();
  public void ReadZonesOn()
    { ReadZonesOn_59(); }

  private native void ReadZonesOff_60();
  public void ReadZonesOff()
    { ReadZonesOff_60(); }

  private native void SetUse64BitLabels_61(boolean id0);
  public void SetUse64BitLabels(boolean id0)
    { SetUse64BitLabels_61(id0); }

  private native boolean GetUse64BitLabels_62();
  public boolean GetUse64BitLabels()
    { return GetUse64BitLabels_62(); }

  private native void Use64BitLabelsOn_63();
  public void Use64BitLabelsOn()
    { Use64BitLabelsOn_63(); }

  private native void Use64BitLabelsOff_64();
  public void Use64BitLabelsOff()
    { Use64BitLabelsOff_64(); }

  private native boolean GetCopyDataToCellZones_65();
  public boolean GetCopyDataToCellZones()
    { return GetCopyDataToCellZones_65(); }

  private native void SetCopyDataToCellZones_66(boolean id0);
  public void SetCopyDataToCellZones(boolean id0)
    { SetCopyDataToCellZones_66(id0); }

  private native void CopyDataToCellZonesOn_67();
  public void CopyDataToCellZonesOn()
    { CopyDataToCellZonesOn_67(); }

  private native void CopyDataToCellZonesOff_68();
  public void CopyDataToCellZonesOff()
    { CopyDataToCellZonesOff_68(); }

  private native void SetUse64BitFloats_69(boolean id0);
  public void SetUse64BitFloats(boolean id0)
    { SetUse64BitFloats_69(id0); }

  private native boolean GetUse64BitFloats_70();
  public boolean GetUse64BitFloats()
    { return GetUse64BitFloats_70(); }

  private native void Use64BitFloatsOn_71();
  public void Use64BitFloatsOn()
    { Use64BitFloatsOn_71(); }

  private native void Use64BitFloatsOff_72();
  public void Use64BitFloatsOff()
    { Use64BitFloatsOff_72(); }

  private native void SetRefresh_73();
  public void SetRefresh()
    { SetRefresh_73(); }

  private native void SetParent_74(vtkOpenFOAMReader id0);
  public void SetParent(vtkOpenFOAMReader id0)
    { SetParent_74(id0); }

  private native int MakeInformationVector_75(vtkInformationVector id0,String id1);
  public int MakeInformationVector(vtkInformationVector id0,String id1)
    { return MakeInformationVector_75(id0,id1); }

  private native boolean SetTimeValue_76(double id0);
  public boolean SetTimeValue(double id0)
    { return SetTimeValue_76(id0); }

  private native long GetTimeValues_77();
  public vtkDoubleArray GetTimeValues() {
    long temp = GetTimeValues_77();

    if (temp == 0) return null;
    return (vtkDoubleArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int MakeMetaDataAtTimeStep_78(boolean id0);
  public int MakeMetaDataAtTimeStep(boolean id0)
    { return MakeMetaDataAtTimeStep_78(id0); }

  public vtkOpenFOAMReader() { super(); }

  public vtkOpenFOAMReader(long id) { super(id); }
  public native long   VTKInit();

}
